r40772 - in /branches/upstream/libfile-touch-perl/current: ._Makefile.PL ._test.pl Changes META.yml Touch.pm

jawnsy-guest at users.alioth.debian.org jawnsy-guest at users.alioth.debian.org
Sun Jul 26 19:38:00 UTC 2009


Author: jawnsy-guest
Date: Sun Jul 26 19:37:50 2009
New Revision: 40772

URL: http://svn.debian.org/wsvn/pkg-perl/?sc=1&rev=40772
Log:
[svn-upgrade] Integrating new upstream version, libfile-touch-perl (0.08)

Removed:
    branches/upstream/libfile-touch-perl/current/._Makefile.PL
    branches/upstream/libfile-touch-perl/current/._test.pl
Modified:
    branches/upstream/libfile-touch-perl/current/Changes
    branches/upstream/libfile-touch-perl/current/META.yml
    branches/upstream/libfile-touch-perl/current/Touch.pm

Modified: branches/upstream/libfile-touch-perl/current/Changes
URL: http://svn.debian.org/wsvn/pkg-perl/branches/upstream/libfile-touch-perl/current/Changes?rev=40772&op=diff
==============================================================================
--- branches/upstream/libfile-touch-perl/current/Changes (original)
+++ branches/upstream/libfile-touch-perl/current/Changes Sun Jul 26 19:37:50 2009
@@ -1,5 +1,8 @@
 Revision history for Perl extension File::Touch.
 
+0.07  Sat Jul 25 12:54 2009
+        - BUGFIX last fix caused probs (thanks Reini Urban)
+          see https://rt.cpan.org/Ticket/Display.html?id=48183
 0.06  Tue Mar 24 11:22:13 2009
         - now works on systems lacking O_NONBLOCK
 	  (thanks Ronald Fischer)

Modified: branches/upstream/libfile-touch-perl/current/META.yml
URL: http://svn.debian.org/wsvn/pkg-perl/branches/upstream/libfile-touch-perl/current/META.yml?rev=40772&op=diff
==============================================================================
--- branches/upstream/libfile-touch-perl/current/META.yml (original)
+++ branches/upstream/libfile-touch-perl/current/META.yml Sun Jul 26 19:37:50 2009
@@ -1,10 +1,20 @@
-# http://module-build.sourceforge.net/META-spec.html
-#XXXXXXX This is a prototype!!!  It will change in the future!!! XXXXX#
-name:         File-Touch
-version:      0.06
-version_from: Touch.pm
-installdirs:  site
-requires:
-
-distribution_type: module
-generated_by: ExtUtils::MakeMaker version 6.30
+--- #YAML:1.0
+name:               File-Touch
+version:            0.08
+abstract:           ~
+author:  []
+license:            unknown
+distribution_type:  module
+configure_requires:
+    ExtUtils::MakeMaker:  0
+build_requires:
+    ExtUtils::MakeMaker:  0
+requires:  {}
+no_index:
+    directory:
+        - t
+        - inc
+generated_by:       ExtUtils::MakeMaker version 6.50
+meta-spec:
+    url:      http://module-build.sourceforge.net/META-spec-v1.4.html
+    version:  1.4

Modified: branches/upstream/libfile-touch-perl/current/Touch.pm
URL: http://svn.debian.org/wsvn/pkg-perl/branches/upstream/libfile-touch-perl/current/Touch.pm?rev=40772&op=diff
==============================================================================
--- branches/upstream/libfile-touch-perl/current/Touch.pm (original)
+++ branches/upstream/libfile-touch-perl/current/Touch.pm Sun Jul 26 19:37:50 2009
@@ -3,7 +3,7 @@
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(touch);
-$VERSION = "0.06";
+$VERSION = "0.08";
 use warnings;
 use strict;
 
@@ -14,28 +14,19 @@
 
 my $SYSOPEN_MODE = O_WRONLY|O_CREAT;
 eval {
-    $SYSOPEN_MODE |= &{ $Fcntl::{'O_NONBLOCK'} };
+    $SYSOPEN_MODE |= O_NONBLOCK;
 };
 if($@) {
-    if($@ =~ /Your vendor has not defined/) {
-	# OK, we don't have O_NONBLOCK:
-	# probably running on Windows.
-    } else {
-	die "$@"; # Rethrow exception, must be something different
-    }
-}
-
-
-
-
-
-foreach my $Fcntl_sym (keys %Fcntl::){
-    if($Fcntl_sym eq 'O_NONBLOCK'){
-	$SYSOPEN_MODE |= &{ $Fcntl::{'O_NONBLOCK'} };
-	last;
-    }
-}
-
+    # OK, we don't have O_NONBLOCK:
+    # probably running on Windows.
+}
+eval {
+    $SYSOPEN_MODE |= O_NOCTTY;
+};
+if($@) {
+    # OK, we don't have O_NOCTTY:
+    # probably running on Windows.
+}
 
 sub new
 {




More information about the Pkg-perl-cvs-commits mailing list